@@ -60,8 +60,8 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.32.1 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
+$^V eq 5.34.0 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
@@ -76,7 +76,7 @@ M`0```*2-``"DC0$`I(T!`)P"``"P$@``!@```````0`"````K(T``*R-`0"L
 MC0$`&`$``!@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
 M```$````4>5T9```````````````````````````!@```!````!2Y71DI(T`
 M`*2-`0"DC0$`7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
-M<V\N,P`````$````%`````,```!'3E4`5:*EC%AO#2CRYVXZ=!W;/0BAZ`,$
+M<V\N,P`````$````%`````,```!'3E4`(D?<Q!R`4J+X8#F2R&H!%-+;//<$
 M````$`````$```!'3E4```````,````"`````````#T```!,````"`````@`
 M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"```````````3```
 M``````!-````3@```%``````````40````````!2````4P```%0```!5````
@@ -152,7 +152,7 @@ M<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I
 M;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F
 M:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T
 M=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L
-M<U]005)?0D]/5`!'3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XS,B]C;W)E
+M<U]005)?0D]/5`!'3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XS-"]C;W)E
 M7W!E<FPO0T]210`````````"``(``@`"``(````#``(``@`"``0``@````(`
 M``````(``@`"``(``@`"`````````````@`"`````P````(``P`"``(`````
 M``(``@`"`````@````,``@```````@`"`````````````@````(``@````(`
@@ -204,7 +204,7 @@ M`!"-Y04@H.$&8(_@`Q"`YT`1G^4`,*#A`1"/X`P`EN5T___K`$!0XB<```HH
 M49_E&&"-X@50C^`,`)7E'___ZQ@!G^4&$*#A``"/X*<``.L``%#C(```"@0Q
 MG^4#,(_@#`"3Y0#__^M<___K]""?Y;0PG^4"((_@`S"2YP`@D^4<,)WE`B`S
 MX",``!H$`*#A(-"-XG"`O>@1___KR""?Y0``4.,"((_@#`""Y1L```KJ_O_K
-MA#"?Y0-`E.<``)3E?/__ZTE7P.6<___J#`"6Y6/__^L`0*#AT___Z@@`E>4`
+MA#"?Y0-`E.<``)3E?/__ZT=7P.6<___J#`"6Y6/__^L`0*#AT___Z@@`E>4`
 M`%#C`0``"DT(`.O9___J>`"?Y080H.$``(_@>P``ZP``4.,(`(7ETO__"O7_
 M_^I'___K$#"@X[;__^K;_O_K`0"@XPS__^NT>`$`#`$``)1X`0`H`0``,`$`
 M`!@!```4`0``<'D!`'!Y`0!8-@``/#8```!Y`0!`"@``U'@!`(@S``"L>`$`
